summaryrefslogtreecommitdiffstats
path: root/lib/qextfileinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/qextfileinfo.h')
-rw-r--r--lib/qextfileinfo.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/qextfileinfo.h b/lib/qextfileinfo.h
index 488e4e5b..1fbe1093 100644
--- a/lib/qextfileinfo.h
+++ b/lib/qextfileinfo.h
@@ -77,7 +77,7 @@ public:
static KURL path(const KURL &);
/** Returns the user's home directory as an url. */
static KURL home();
/** A slightly better working alternative of KIO::NetAccess::exists().
Checks for the existance of the url. readingOnly is true if we check if
the url is readable, and false if we check if it is writable.*/
static bool exists(const KURL& url, bool readingOnly, TQWidget *window);
@@ -99,7 +99,7 @@ private:
bool bJobOK;
static TQString lastErrorMsg;
- KIO::UDSEntry m_entry;
+ TDEIO::UDSEntry m_entry;
KURL::List dirListItems;
TQDict<KFileItem> detailedDirListItems;
TQPtrList<TQRegExp> lstFilters;
@@ -107,10 +107,10 @@ private:
TQString m_listStartURL;
private slots:
- void slotListResult(KIO::Job *job);
- void slotResult(KIO::Job * job);
- void slotNewEntries(KIO::Job *job, const KIO::UDSEntryList& udsList);
- void slotNewDetailedEntries(KIO::Job *job, const KIO::UDSEntryList& udsList);
+ void slotListResult(TDEIO::Job *job);
+ void slotResult(TDEIO::Job * job);
+ void slotNewEntries(TDEIO::Job *job, const TDEIO::UDSEntryList& udsList);
+ void slotNewDetailedEntries(TDEIO::Job *job, const TDEIO::UDSEntryList& udsList);
public slots:
/** Timeout occurred while waiting for some network function to return. */
void slotTimeout();
@@ -77,7 +77,7 @@ public:
/** Returns the user's home directory as an url. */
static KURL home();
- /** A slightly better working alternative of KIO::NetAccess::exists().
+ /** A slightly better working alternative of TDEIO::NetAccess::exists().
Checks for the existance of the url. readingOnly is true if we check if
the url is readable, and false if we check if it is writable.*/